@@ -127,7 +127,7 @@ class ImageRecognition(object):
             # get inception variable name
             base_var_list = tf.get_collection(tf.GraphKeys.GLOBAL_VARIABLES)
 
-        with tf.variable_scope('inception_v4'):
+        with tf.variable_scope('inceptionV4'):
             size = out.get_shape().as_list()[1]
             while(True):
                 if size == 1:
@@ -238,7 +238,7 @@ class ImageRecognition(object):
             batch_size {integer} -- the size of the batch
             image_name_list {list of string} -- the list of image name
         """
-        file_list = get_filenames(os.path.join(dataset_path + self.classes[0]))
+        file_list = get_filenames(os.path.join(dataset_path, self.classes[0]))
         self.file_num = len(file_list) * len(self.classes)
         self.tmp_batch_size = batch_size
 
@@ -313,7 +313,6 @@ class ImageRecognition(object):
                         out_tensor): 
         x_val, y_val = next(val_generator)
         iteration_needed = math.ceil(self.file_num / self.tmp_batch_size)
-        print (iteration_needed)
 
         losses = [] 
         accs = [] 
@@ -342,6 +341,8 @@ class ImageRecognition(object):
         acc = np.mean(np.array(accs))
         recall = np.mean(np.array(recalls))
         precision = np.mean(np.array(precisions))
+
+        return loss, acc, precision, recall
     
 
     def optimize(self, 
@@ -417,8 +418,8 @@ class ImageRecognition(object):
                 saver.save(session, path_tosave_model)
 
             print (">> epoch: {}, train loss: {}, val loss: {}, val acc: {}, val recall: {}, val prec: {} {}".format(i, round(t_loss, 3), 
-                                                                                    round(val_loss, 3), round(val_acc, 3), round(val_acc, 3), 
-                                                                                    round(val_recall, 3), round(val_precision, 3), sign))
+                                                                                    round(val_loss, 3), round(val_acc, 3), round(val_recall, 3), 
+                                                                                    round(val_precision, 3),  sign))
         
 
     
\ No newline at end of file
